aboutsummaryrefslogtreecommitdiff
path: root/background/main.js
diff options
context:
space:
mode:
authorjahoti <jahoti@tilde.team>2021-07-19 00:00:00 +0000
committerjahoti <jahoti@tilde.team>2021-07-19 00:00:00 +0000
commit6b12a034efe8918eb45f09aa5aad94177eb51049 (patch)
tree8ef97158020fd4ba02fe740f491f9a1a3fe17498 /background/main.js
parentecb787046271de708b94da70240713e725299d86 (diff)
downloadbrowser-extension-6b12a034efe8918eb45f09aa5aad94177eb51049.tar.gz
browser-extension-6b12a034efe8918eb45f09aa5aad94177eb51049.zip
Refer to the extension consistently as "Hachette" and remove TODOS.org
from the copyright file
Diffstat (limited to 'background/main.js')
-rw-r--r--background/main.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/background/main.js b/background/main.js
index da408f9..ffa814e 100644
--- a/background/main.js
+++ b/background/main.js
@@ -1,5 +1,5 @@
/**
* Myext main background script
*
* Copyright (C) 2021 Wojtek Kosior
* Redistribution terms are gathered in the `copyright' file.
@@ -22,7 +22,7 @@ start_page_actions_server();
start_policy_injector();
start_page_info_server();
-async function init_myext(install_details)
+async function init_ext(install_details)
{
console.log("details:", install_details);
if (install_details.reason != "install")
@@ -44,6 +44,6 @@ async function init_myext(install_details)
}
}
-browser.runtime.onInstalled.addListener(init_myext);
+browser.runtime.onInstalled.addListener(init_ext);
-console.log("hello, myext");
+console.log("hello, hachette");
@@ -1,5 +1,5 @@
/**
- * Myext main background script
+ * Hachette main background script
*
* Copyright (C) 2021 Wojtek Kosior